# zdg
Library to easily create a directed graph where each node is a Docker container and each edge is a ZMQ point-to-point socket.
The main output is a docker compose file to start the directed graph structure. 

## Install
```
pip install zdg
```


## Usage
